pub struct Settings;Expand description
Settings struct is empty currently
Implementations
Sourceimpl Settings
Settings implements the interface to use outside the module
impl Settings
Settings implements the interface to use outside the module
Sourcepub fn load(submod: &str) -> Result<Arc<SettingsDerive>, SettingsError>
pub fn load(submod: &str) -> Result<Arc<SettingsDerive>, SettingsError>
Load dataset specific settings typically identified by two-letter country code e.g. au This is expected to conform ISO 3166-1_alpha-2 Except lowercase due to Rust RFC 430
let au_config = gis_puller::settings::Settings::load("au");Trait Implementations